@@ -1,7 +1,7 @@
 next_month <-
 function(x = Sys.Date(),
          n = 1, 
-         part = c("all", "start", "end", "sequence", "length")){
+         part = getOption("timeperiodsR.parts")){
   
   if ( ! "Date" %in% class(x) ) {
     x <- as.Date(x)
@@ -11,11 +11,11 @@ function(x = Sys.Date(),
   stop  <- start + months(1) - days(1)
   out   <- custom_period(start, stop)
   
-  part <- match.arg(part)
+  part <- match.arg(part, getOption("timeperiodsR.parts"))
   
-  if ( part %in% c("start", "end", "sequence", "length") ) {
-    return(out[[part]]) 
-  } else {
+  if ( part == "all" ) {
     return(out) 
-  }
+  } else {
+    return(out[[part]]) 
+  } 
 }
